# coding=utf-8
# coding=utf-8

import logging
from collections import namedtuple
import os
from typing import NamedTuple

import httplib2
from oauth2client.tools import argparser
from oauth2client import client
from oauth2client import tools
from oauth2client.file import Storage
from apiclient import discovery
import mammut
from mammut.common import GOOGLE_API_AUTH_LOCAL_WEBSERVER
from mammut.common import GOOGLE_API_AUTH_LOCAL_CREDENTIAL
from mammut.common.google_api import GoogleAPI
from mammut.common.storage.storage_base import SlidesStorageBase

logger = logging.getLogger()


class SlideElement(NamedTuple):
    slideNumber: int
    elementType: str
    content: str


class GoogleStorageSlide(SlidesStorageBase, GoogleAPI):
    def __init__(self):
        SlidesStorageBase.__init__(self)

    @GoogleAPI.ensure_credentials_and_read_limits
    def get_slide_elements(self, presentation_id):
        def getTextFromShape(shape):
            text = ""
            for i, t in enumerate(shape.get("text").get("textElements")):
                if not t.get("textRun") is None:
                    text = text + t.get("textRun").get("content")
            return text[: len(text) - 1]

        presentation = (
            GoogleStorageSlide.SLIDES_SERVICE.presentations()
            .get(presentationId=presentation_id)
            .execute()
        )
        slides = presentation.get("slides")
        namTupleSlideElements = []
        for i, slide in enumerate(slides):
            for j, element in enumerate(slide.get("pageElements")):
                if not element.get("shape") is None:
                    if not element.get("shape").get("text") is None:
                        text = getTextFromShape(element.get("shape"))
                        namTupleSlideElements.append(
                            (SlideElement(j + 1, "text", text),)
                        )
                else:
                    if not element.get("image") is None:
                        imgUrl = element.get("image").get("sourceUrl")
                        namTupleSlideElements.append(
                            (SlideElement(j + 1, "image", imgUrl),)
                        )
        return namTupleSlideElements



from enum import Enum


class ElasticsearchParams(Enum):
    """
    Enum with the list of constant required to interact with Elasticsearch.
    """

    RESULT_RESPONSE_KEY = "result"
    FOUND_RESPONSE_KEY = "found"
    SOURCE_RESPONSE_KEY = "_source"

    def __repr__(self):
        return str(self.value)

    def __call__(self, *args, **kwargs):
        return str(self.value)


class DictionaryTable(Enum):
    """
    Enum with the list of constant required by the Dictionary table.
    """

    LEMMA_COLUMN_NAME = "lemma"
    WORD_TYPE_COLUMN_NAME = "word_type"
    REGIONAL_SETTINGS_LEMMA_COLUMN_NAME = "regional_settings_lemma"
    AFI_COLUMN_NAME = "AFI"
    POS_PARADIGM_COLUMN_NAME = "pos_paradigm"
    MORPH_PARADIGM_COLUMN_NAME = "morph_paradigm"
    MISS_PARADIGM_COLUMN_NAME = "miss_paradigm"
    FET_PARADIGM_COLUMN_NAME = "fet_paradigm"
    DEFINITION_INDEX_COLUMN_NAME = "definition_index"
    FEATURES_COLUMN_NAME = "features"
    SOURCE_COLUMN_NAME = "source"
    TOPIC_COLUMN_NAME = "topic"
    DEFINITION_COLUMN_NAME = "definition"
    REGIONAL_SETTINGS_DEFINITION_COLUMN_NAME = "regional_settings_definition"
    DATE_COLUMN_NAME = "date"
    TIMESTAMP_COLUMN_NAME = "timestamp"
    SENSE_LEMMA_COLUMN_NAME = "sense_lemma"
    SYNONYM_WORDS_COLUMN_NAME = "synonym_words"

    def __repr__(self):
        return str(self.value)

    def __call__(self, *args, **kwargs):
        return str(self.value)





# coding=utf-8
from nltk.probability import *

from mammut.common import google_api
from mammut.common.util import StringEnum

from mammut.models import (
    NGRAM_VIEWER_SMOOTHING,
    LEXICAL_RELEVANCE_INDEX_ESTIMATOR_CONSOLIDATE_STATS,
    LEXICAL_RELEVANCE_INDEX_ESTIMATOR_AUMENTATION,
    LEXICAL_RELEVANCE_INDEX_ESTIMATOR_USAGE_SOURCE,
)
from mammut.models import NGRAM_VIEWER_YEAR_START
from mammut.models import NGRAM_VIEWER_YEAR_END
from mammut.models import NGRAM_VIEWER_CASE_INSENSITIVE


class BaseNGramProbDist(ProbDistI):
    def __init__(self, regional_settings):
        self.regional_settings = regional_settings
        self._current_max = float(0.0)
        self._current_cond_total = float(0.0)

    def freqdist(self):
        raise NotImplementedError()

    def B(self):
        raise NotImplementedError()

    def has_sample(self, sample):
        raise NotImplementedError()

    def prob(self, sample, add=True):
        raise NotImplementedError()

    def cond_prob(self, sample):
        raise NotImplementedError()

    def max(self):
        return self._current_max

    def samples(self):
        raise NotImplementedError()

    def __repr__(self):
        """
        :rtype: str
        :return: A string representation of this ``ProbDist``.
        """
        return "<NGramProbDist based on %d samples>" % self.B()


class MuteNGramProbDist(BaseNGramProbDist):
    def __init__(self, regional_settings):
        BaseNGramProbDist.__init__(self, regional_settings)
        self._samples = set()

    def freqdist(self):
        raise ValueError("A MuteNGramProbDist is a dummy distribution.")

    def B(self):
        return len(self._samples)

    def has_sample(self, sample):
        return sample in self._samples

    def prob(self, sample, add=True):
        if add:
            self._samples.add(sample)
        return -1.0

    def cond_prob(self, sample, add=True):
        if add:
            self._samples.add(sample)
        return -1.0

    def samples(self):
        return self._samples


class GoogleNGramProbDistMode(StringEnum):
    UNORDERED_TRIGRAM = "utrigram"
    UNORDERED_BIGRAM = "ubigram"
    UNIGRAM = "unigram"


class GoogleNGramProbDist(BaseNGramProbDist):
    def __init__(self, regional_settings, mode: GoogleNGramProbDistMode):
        BaseNGramProbDist.__init__(self, regional_settings)
        self.mode = mode
        self._prob_dict = {}

    def freqdist(self):
        raise ValueError("A GoogleNGramProbDist is a online service.")

    def B(self):
        return len(self._prob_dict)

    def has_sample(self, sample):
        return sample in self._prob_dict

    def prob(self, sample, add=True):
        val = 0.0
        if sample not in self._prob_dict:
            if self.mode == GoogleNGramProbDistMode.UNORDERED_TRIGRAM:
                val = google_api.unordered_trigram_frecuency(
                    sample,
                    self.regional_settings,
                    NGRAM_VIEWER_SMOOTHING,
                    NGRAM_VIEWER_YEAR_START,
                    NGRAM_VIEWER_YEAR_END,
                    NGRAM_VIEWER_CASE_INSENSITIVE,
                )
            elif self.mode == GoogleNGramProbDistMode.UNORDERED_BIGRAM:
                val = google_api.unordered_bigram_frecuency(
                    sample,
                    self.regional_settings,
                    NGRAM_VIEWER_SMOOTHING,
                    NGRAM_VIEWER_YEAR_START,
                    NGRAM_VIEWER_YEAR_END,
                    NGRAM_VIEWER_CASE_INSENSITIVE,
                )
            else:
                val = google_api.unigram_frecuency(
                    sample,
                    self.regional_settings,
                    NGRAM_VIEWER_SMOOTHING,
                    NGRAM_VIEWER_YEAR_START,
                    NGRAM_VIEWER_YEAR_END,
                    NGRAM_VIEWER_CASE_INSENSITIVE,
                )
            if add:
                self._prob_dict[sample] = val
                if val > self._current_max:
                    self._current_max = val
                self._current_cond_total = float(self._current_cond_total) + val
        else:
            val = self._prob_dict[sample]
        return val

    def cond_prob(self, sample, add=True):
        res = float(self.prob(sample, add)) / float(self._current_cond_total)
        return res

    def samples(self):
        return self._prob_dict.keys()


class LexicalRelevanceIndexEstimator:
    def __init__(self, regional_settings, token_freqdist: FreqDist):
        self.regional_settings = regional_settings
        self.prob_d_u_c_base_prior = MLEProbDist(token_freqdist)
        if LEXICAL_RELEVANCE_INDEX_ESTIMATOR_USAGE_SOURCE == "GoogleNgram":
            self.prob_u = GoogleNGramProbDist(
                self.regional_settings, GoogleNGramProbDistMode.UNIGRAM
            )
        else:
            self.prob_u = MuteNGramProbDist(self.regional_settings)

    def add_new_sample(self, sample):
        return self.prob_u.prob(sample)

    def consolidate_stats(self):
        if self.prob_d_u_c_base_prior.freqdist().B() != self.prob_u.B():
            for s in self.prob_d_u_c_base_prior.samples():
                if not self.prob_u.has_sample(s):
                    self.add_new_sample(s)

    def get_index(self, sample, add=True):
        if LEXICAL_RELEVANCE_INDEX_ESTIMATOR_CONSOLIDATE_STATS and not add:
            self.consolidate_stats()
        prob_ng_cond_prob = self.prob_u.cond_prob(sample, add)
        prob_d_u_c_base_prior_prob = self.prob_d_u_c_base_prior.prob(sample)
        prob_ng_prob = self.prob_u.prob(sample, add)
        unnormalized_prob = float(prob_ng_cond_prob) * float(prob_d_u_c_base_prior_prob)
        if unnormalized_prob:
            normalized_prob = float(unnormalized_prob) / float(prob_ng_prob)
            aumented_prob = (
                float(LEXICAL_RELEVANCE_INDEX_ESTIMATOR_AUMENTATION) * normalized_prob
            )
            return aumented_prob
        else:
            return 0.0



from mammut.curriculum.models.hugging_face.pre_trained_model import (
    HuggingFacePreTrainedModel,
)
import mammut.curriculum.report as report
from transformers import (
    Trainer,
    TrainingArguments,
    RobertaForTokenClassification,
    RobertaForQuestionAnswering,
    DataCollatorForTokenClassification,
    RobertaForSequenceClassification,
    RobertaConfig,
    RobertaTokenizer,
    RobertaTokenizerFast,
)
from datasets import *
from pandas import DataFrame
from typing import Dict, List
import logging
from sklearn.metrics import precision_recall_fscore_support, accuracy_score
from mammut.common.corpus.corpus_map import CorpusMap

from mammut.curriculum.core.mammut_session_context import MammutSessionContext
from mammut.curriculum.models.hugging_face.preprocess_data import (
    TokenClassificationPreprocess,
    HFPreprocessForQuestionAnswering,
    HFPreprocessForParaphraseClassification,
)

log = logging.getLogger(__name__)


class HuggingFaceRobertaTokenClassificationModel(
    HuggingFacePreTrainedModel, TokenClassificationPreprocess
):
    """This is a wrapper for the Roberta Model transformer.

    https://huggingface.co/transformers/model_doc/roberta.html#robertamodel

    """

    def __init__(
        self,
        parameters: Dict,
        course_id: int,
        lesson_id: int,
        mammut_session_context: MammutSessionContext,
        corpus_id: int,
        corpus_map: CorpusMap,
    ):
        """
       Args:
          parameters: The parameters parsed JSON included the parameters required:
                - specific parameters for the current model.
                - tokenizer_parameters(Dict): include the tokenizer parameters to forward to this model.
                - preprocess_parameters(Dict): include the preprocess parameters to forward to this model.
                - task(str): concrete task in token classification model ("ner", "pos" or "chunk").
          course_id (int): the course ID to which this model belongs.
          lesson_id (int): the lesson ID to which this model belongs.
          mammut_session_context: Mammut session context with general information about
               current curriculum instance.
          corpus_id(str): 'corpus_id' value in datasource retrieved data.
       """
        tokenizer_parameters: Dict = parameters["tokenizer_parameters"]
        preprocess_parameters: Dict = parameters["preprocess_parameters"]
        task: str = parameters["task"]
        HuggingFacePreTrainedModel.__init__(
            self,
            parameters,
            course_id,
            lesson_id,
            mammut_session_context,
            corpus_id,
            corpus_map,
        )
        TokenClassificationPreprocess.__init__(
            self, tokenizer_parameters, preprocess_parameters, task
        )
        self.labels: List

    def load_pretrained_models(self, dataset):
        """Load the pretrained model for this ROBERTA wrapper. """

        config = RobertaConfig.from_pretrained(self._name_or_path)
        self.labels = self._load_labels(dataset)
        config.num_labels = len(self.labels)
        self._model = RobertaForTokenClassification(config)

    def _load_tokenizer(self):
        tokenizer = RobertaTokenizerFast.from_pretrained(
            self._name_or_path, **self.tokenizer_parameters
        )
        return tokenizer

    def _load_labels(self, dataset):
        """To train a model we will need to specify the number of labels
        in the data source. This method receives the corpus
        (Dataset, DataDict or DataFrame) and returns a list with the labels.
        """

        if type(dataset) == DatasetDict:
            labels = (
                dataset["train"].features[f"{self.task}_tags"].feature.names
            )
            return labels
        elif type(dataset) == Dataset:
            labels = dataset.features[f"{self.task}_tags"].feature.names
            return labels
        elif type(dataset) == DataFrame:
            labels = sorted(
                list(
                    set(
                        [
                            lbls
                            for sublist in dataset.tags.tolist()
                            for lbls in sublist
                        ]
                    )
                )
            )
            return [labels]
        else:
            raise ValueError(
                "The data format should be Dataset, DictDataset or Dataframe. Verify your data format"
            )

    def train(self, mammut_session_context: MammutSessionContext, **kwargs):
        """Train the Roberta base model in the lesson.
        Args:
            ** mammut_session_context
            ** num_epochs(float): total number of training epochs to perform, defaults to 3.0.
                If not an integer, will perform the decimal part percents of the last epoch
                before stopping training.
            ** training_batch_size(int): batch size per device during training, defaults to 8.
            ** eval_batch_size(int): batch size for evaluation, defaults to 8.
        """
        num_epochs = self.parameters["num_epochs"]
        training_batch_size = self.parameters["train_batch_size"]
        evaluation_batch_size = self.parameters["eval_batch_size"]
        warmup_steps = 500
        weight_decay = 0.01
        corpus = kwargs["corpus"]
        train_dataset = corpus["train"]
        eval_dataset = corpus["validation"]

        def compute_metrics(pred):
            labels = pred.label_ids
            preds = pred.predictions.argmax(-1)
            precision, recall, f1, _ = precision_recall_fscore_support(
                labels, preds, average="micro"
            )
            acc = accuracy_score(labels, preds)
            return {
                "accuracy": acc,
                "f1": f1,
                "precision": precision,
                "recall": recall,
            }

        data_collator = DataCollatorForTokenClassification(self._tokenizer)
        training_args = TrainingArguments(
            output_dir="./results",
            num_train_epochs=num_epochs,
            per_device_train_batch_size=training_batch_size,
            per_device_eval_batch_size=evaluation_batch_size,
            warmup_steps=warmup_steps,
            weight_decay=weight_decay,
            logging_dir="./logs",
        )
        trainer = Trainer(
            model=self._model,
            tokenizer=self._tokenizer,
            args=training_args,
            train_dataset=train_dataset,
            eval_dataset=eval_dataset,
            data_collator=data_collator,
            compute_metrics=compute_metrics,
        )
        return trainer.train()


class HuggingFaceRobertaQuestionAnsweringModel(
    HuggingFacePreTrainedModel, HFPreprocessForQuestionAnswering
):
    """This is a wrapper for the RobertaForQuestionAnswering model
    """

    def __init__(
        self,
        parameters: Dict,
        course_id: int,
        lesson_id: int,
        mammut_session_context: MammutSessionContext,
        corpus_id: int,
        corpus_map: CorpusMap,
    ):
        """
        Args:
          parameters: The model parameters parsed JSON.
          course_id (int): the course ID to which this model belongs.
          lesson_id (int): the lesson ID to which this model belongs.
          mammut_session_context: Mammut session context with general information about
               current curriculum instance.
       """
        tokenizer_parameters: Dict = parameters["tokenizer_parameters"]
        preprocess_parameters: Dict = parameters["preprocess_parameters"]

        HuggingFacePreTrainedModel.__init__(
            self,
            parameters,
            course_id,
            lesson_id,
            mammut_session_context,
            corpus_id,
            corpus_map,
        )

        HFPreprocessForQuestionAnswering.__init__(
            self, tokenizer_parameters, preprocess_parameters
        )

    def _load_tokenizer(self):
        self._tokenizer = RobertaTokenizerFast.from_pretrained(
            self._name_or_path, **self.tokenizer_parameters
        )
        return self._tokenizer

    def load_pretrained_models(self):
        """Load the pretrained model for this Roberta wrapper. """
        self._model = RobertaForQuestionAnswering.from_pretrained(
            self._name_or_path
        )

    def train(self,  mammut_session_context: MammutSessionContext, **kwargs):
        """Train this QuestionAnswering model in the lesson.
        Note: nothing to train yet.
        Todo: Collaboration between Mammut Corpus (or other data source) and
            this model needs to be defined.
        """
        corpus = kwargs["corpus"]

        if isinstance(corpus, list):
            train_dataset = corpus[0]
            eval_dataset = corpus[1]
        else:
            train_dataset = corpus["train"]
            eval_dataset = corpus["validation"]

        epochs = self.parameters["num_train_epochs"]
        train_batch = self.parameters["train_batch_size"]
        eval_batch = self.parameters["eval_batch_size"]
        warmup_steps = self.parameters["warmup_steps"]
        weight_decay = self.parameters["weight_decay"]

        training_args = TrainingArguments(
            output_dir='./results',
            num_train_epochs=epochs,
            per_device_train_batch_size=train_batch,
            per_device_eval_batch_size=eval_batch,
            warmup_steps=warmup_steps,
            weight_decay=weight_decay,
            logging_dir="./logs",
        )

        trainer = Trainer(
            model=self._model,
            args=training_args,
            train_dataset=train_dataset,
            eval_dataset=eval_dataset,
        )

        training = trainer.train()

        report.send_message(
            report.CurriculumGeneralDebugMessage(
                "Training HuggingFaceRobertaQuestionAnsweringModel model"
            )
        )
        return training


class HuggingFaceRobertaSequenceClassificationModel(
    HuggingFacePreTrainedModel, HFPreprocessForParaphraseClassification
):
    """This is a wrapper for the RobertaForSequenceClassification model
    https://huggingface.co/transformers/model_doc/bert.html#bertfortokenclassification
    """

    def __init__(
        self,
        parameters: Dict,
        course_id: int,
        lesson_id: int,
        mammut_session_context: MammutSessionContext,
        corpus_id: int,
        corpus_map: CorpusMap,
    ):
        """
        Args:
          parameters: The model parameters parsed JSON.
          course_id (int): the course ID to which this model belongs.
          lesson_id (int): the lesson ID to which this model belongs.
          mammut_session_context: Mammut session context with general information about
               current curriculum instance.
       """
        preprocess_parameters: Dict = parameters["preprocess_parameters"]
        tokenizer_parameters: Dict = parameters["tokenizer_parameters"]
        HuggingFacePreTrainedModel.__init__(
            self,
            parameters,
            course_id,
            lesson_id,
            mammut_session_context,
            corpus_id,
            corpus_map,
        )

        HFPreprocessForParaphraseClassification.__init__(
            self, tokenizer_parameters, preprocess_parameters
        )

    def _load_tokenizer(self):
        self._tokenizer = RobertaTokenizer.from_pretrained(
            self._name_or_path, use_fast=True,
        )
        return self._tokenizer

    def load_pretrained_models(self):
        """Load the pretrained model for this Roberta wrapper. """
        label = self.parameters["num_labels"]
        self._model = RobertaForSequenceClassification.from_pretrained(
            self._name_or_path, num_labels=label
        )

    def train(self, mammut_session_context: MammutSessionContext, **kwargs):
        """Train this classification model in the lesson.
        Note: nothing to train yet.
        Todo: Collaboration between Mammut Corpus (or other data source) and
            this model needs to be defined.
        """
        corpus = kwargs["corpus"]

        if isinstance(corpus, list):
            train_dataset = corpus[0]
            eval_dataset = corpus[1]
        else:
            train_dataset = corpus["train"]
            eval_dataset = corpus["validation"]

        epochs = self.parameters["num_train_epochs"]
        train_batch = self.parameters["train_batch_size"]
        eval_batch = self.parameters["eval_batch_size"]
        warmup_steps = self.parameters["warmup_steps"]
        weight_decay = self.parameters["weight_decay"]

        training_args = TrainingArguments(
            output_dir='./results',
            num_train_epochs=epochs,
            per_device_train_batch_size=train_batch,
            per_device_eval_batch_size=eval_batch,
            warmup_steps=warmup_steps,
            weight_decay=weight_decay,
            logging_dir="./logs",
        )

        trainer = Trainer(
            model=self._model,
            args=training_args,
            train_dataset=train_dataset,
            eval_dataset=eval_dataset,
        )

        training = trainer.train()

        report.send_message(
            report.CurriculumGeneralDebugMessage(
                "Training HuggingFaceRobertasequenceClassificationModel model"
            )
        )
        return training



import ray
from typing import Dict
import logging
import mammut.curriculum.report as report
from mammut.curriculum.models.online_models.ktt_interpretation_model import (
    KttInterpretationModel,
)

logging.basicConfig(level=logging.INFO)
logger = logging.getLogger(__name__)


@ray.remote
class OnlineModelsRegistry:
    """A online models registry designed to be available across the curriculum
    as a Ray actor.

    This registry is a table where keys are tuples of course ID and lesson ID,
    and values are online models actor handles.

    Each online model must be a Ray actor class. Make sure to use @ray.remote.
    Currently, that can't be generalized in a class because ray doesn't support
    inheriting from actor classes. Thus, each online model must use the
    @ray.remote decorator.
    """

    # Table of available online models to instantiate by name.
    _available_models: Dict = {
        KttInterpretationModel.MODEL_NAME: KttInterpretationModel
    }

    def __init__(self):
        self._table: Dict[str, ray.actor.ActorHandle] = {}

    def add_model_entry(
        self, model_name: str, model_handle: ray.actor.ActorHandle,
    ):
        """Adds a new online model to the registry if it doesn't
        exists in the registry.

        Models are stored in a Key value table where the key is
        the model name, and the value is the ActorHandle of the model.

        Keeping the ActorHandle in the table is a safe way to ensure
        the lifecycle of the actor.

        Currently ActorHandles can't be returned by remote functions in Ray
        (https://github.com/ray-project/ray/issues/1222). Because of that,
        named actors are used for online models. Doing so, they can be accessed
        across the Ray cluster using their name.

        Args:
            model_name: name of the model.
            model_handle: Ray actor handle for the model.
        """
        logger.info(
            f"Adding model handle in OnlineModelsRegistry: ({model_name})"
        )
        if model_name not in self._table:
            self._table[model_name] = model_handle

    def has_model(self, model_name: str) -> bool:
        return model_name in self._table

    @staticmethod
    def get_model_instance(model_name, registry_handle, lesson):
        """Returns an online model stored in this registry. If the models doesn't exists,
        it will be created.

        This method is designed this way to centralize the request of a model
        in this registry code. The method needs the name of the online model because
        of (https://github.com/ray-project/ray/issues/1222).

        Args:
            model_name: The model of the online name to retrieve the named actor handle.
            registry_handle: An actor handle for an instance of this registry.
            lesson: The lessson for which the model will be created.

        Raises:
            KeyError if the named online model isn't in the registry.

        Returns:
            Returns the ActorHandle for the requested model.
        """
        registry_has_model = ray.get(
            registry_handle.has_model.remote(model_name)
        )

        if registry_has_model:
            report.send_message(
                report.CurriculumGeneralDebugMessage(
                    "KttInterpretationLesson model found in registry. Reusing model."
                )
            )
            return ray.get_actor(model_name)

        else:
            report.send_message(
                report.CurriculumGeneralDebugMessage(
                    "KttInterpretationLesson model not found in registry. Creating model."
                )
            )
            model_handle = (
                OnlineModelsRegistry._available_models[model_name]
                .options(name=model_name)
                .remote(
                    lesson.parameters_dict, lesson.course, lesson.lesson_id
                )
            )
            registry_handle.add_model_entry.remote(
                KttInterpretationModel.MODEL_NAME, model_handle
            )
            return model_handle



from typing import List, Optional, Set
from mammut.curriculum.core.curriculum_base import CurriculumBase
from mammut.curriculum.classroom.ray_classroom import RayClassroom
from mammut.curriculum.classroom.classroom_pool import ClassroomPool
from mammut.curriculum.models.online_models.online_models import OnlineModelsRegistry
from mammut.curriculum.course.course import Course
from mammut.curriculum.course.course_state import CourseState
from mammut.curriculum.core.curriculum_state_machine import (
    CurriculumStateMachineMixin,
)
from mammut.curriculum.report.reporters.ray_reporter_registry import (
    RayReportersRegistry,
)
import mammut.curriculum.report as report
import threading
import time
import logging
import ray
import os

log = logging.getLogger(__name__)


class DistributedCurriculum(CurriculumBase, CurriculumStateMachineMixin):
    """Models the Curriculum learning in a multi classroom environment.

    A Curriculum is composed of a set of courses.
    Each course attempts to train language competences that belongs
    to a language level (https://doc.mammut.io/docs_es/framework/language_arquitecture/).

    The courses in a Curriculum forms a flowchart, which is
    a directed acyclic graph. The flowchart implies that courses are
    meant to be progressive, which allows to organize them into academic
    periods.
    """

    def __init__(
        self,
        package_id: str,
        standard_spreadsheet_id: str,
        curriculum_base_sheet_title: str = "curriculum",
        lessons_base_sheet_title: str = "lessons",
        assessments_sheet_title: str = "assessments",
        standard_base_sheet_title: str = "base",
        standard_dict_sources_sheet_title: str = "dict-sources",
        standard_pos_sheet_title: str = "pos-tags",
        standard_features_sheet_title: str = "features",
        standard_dimensions_sheet_title: str = "dimensions",
        dictionary_sheet_title: str = "dictionary",
        standard_functionals_sheet_title: str = "functionals",
        standard_non_functionals_sheet_title: str = "non-functionals",
        standard_primes_sheet_title: str = "primes",
        standard_synonym_sheet_title: str = "synonym",
        synonym_sheet_title: str = "synonym",
        progress_sheet_title: str = "progress",
        package_id_is_spreadsheet: bool = False,
        show_progress: bool = True,
        enable_ktt_interpretation: bool = True,
    ):
        super(DistributedCurriculum, self).__init__(
            package_id,
            standard_spreadsheet_id,
            curriculum_base_sheet_title,
            lessons_base_sheet_title,
            assessments_sheet_title,
            standard_base_sheet_title,
            standard_dict_sources_sheet_title,
            standard_pos_sheet_title,
            standard_features_sheet_title,
            standard_dimensions_sheet_title,
            dictionary_sheet_title,
            standard_functionals_sheet_title,
            standard_non_functionals_sheet_title,
            standard_primes_sheet_title,
            standard_synonym_sheet_title,
            synonym_sheet_title,
            progress_sheet_title,
            package_id_is_spreadsheet,
            show_progress,
            enable_ktt_interpretation=enable_ktt_interpretation,
        )
        self._next_academic_period_courses: Set[Course] = set()
        self._next_academic_period_assigned_classrooms: List[
            RayClassroom
        ] = list()
        self.classroom_pool: Optional[ClassroomPool] = None
        """
        Attribute flag to indicate auto transition
        after first academic period has been executed.
        """
        self._started: bool = False
        self._processing_polling_thread: threading.Thread = None
        self._remote_reporting_listener_thread: threading.Thread = None

        # Todo: this search path fot KtT Transducer must be taken from configuration.
        #   Currently, there's another branch incorporating configuration.
        ktt_jar_search_path = (
            os.path.expanduser("~")
            + "/.mammut-py/ktt/mammut-transducer-ktt.jar"
        )

        # initializes the remote RayReportersRegistry actor
        # Todo: this ray initialization will probably change of place in the future.
        if not ray.is_initialized():
            ray.init(
                log_to_driver=False,
                job_config=ray.job_config.JobConfig(
                    code_search_path=[ktt_jar_search_path]
                ),
            )

        self._mammut_session_context.main_report_actor_handle = (
            RayReportersRegistry.remote()
        )

        self._mammut_session_context.online_models_registry = (
            OnlineModelsRegistry.remote()
        )

    def _compute_next_academic_period(self):
        """Select the set of courses and classrooms for the next academic period.
        """
        courses = list(self.flowchart.graph.nodes)
        approved_courses: List[Course] = []
        unapproved_courses: List[Course] = []

        """
            Courses that are already approved don't count. 
        """
        for c in courses:
            if not c.approved():
                unapproved_courses.append(c)
            else:
                approved_courses.append(c)

        """
            All courses approved.
        """
        if not unapproved_courses:
            report.send_message(
                report.CurriculumGeneralInfoMessage(
                    "All courses has been approved. Curriculum Completed."
                )
            )
            self._next_academic_period_courses = []
            self.trigger(self.CURRICULUM_COMPLETED_TRIGGER)
            return

        """
            Computes the next academic period based on 
            the minimum academic period course(s) that haven't be approved. 
            Only courses with the same academic period can be concurrently processed.
        """
        min_academic_period_course = min(
            unapproved_courses, key=lambda course: course.academic_period
        )

        """
            Assign the unapproved courses from the lowest academic period 
        """
        self._next_academic_period_courses = [
            c
            for c in unapproved_courses
            if c.academic_period == min_academic_period_course.academic_period
        ]

        """
            Right now, the max number of classrooms equals the max number of 
            parallel courses in the academic periods. 
        """
        for i in range(len(self._next_academic_period_courses)):
            self._next_academic_period_assigned_classrooms.append(
                self.classroom_pool.take_out()
            )

        """
            At this point, it is possible to decide if the curriculum 
            failed. If at least one course from the next academic period
            is not allowed, the curriculum failed. 
        """
        if any(
            list(
                map(
                    lambda course: not course.is_allowed(),
                    self._next_academic_period_courses,
                )
            )
        ):
            report.send_message(
                report.CurriculumGeneralWarningMessage(
                    "Curriculum process failed. Maximum retries reached for course."
                )
            )
            self.trigger(self.FAIL_COURSE_TRIGGER)
            return

        """
            At this point, it's safe to make the transition to the 
            next academic period processing cycle. 
        """
        report.send_message(
            report.CurriculumGeneralInfoMessage(
                f"New academic period. [{min_academic_period_course.academic_period}] academic period "
                f"with [{len(self._next_academic_period_courses)}] assigned courses"
            )
        )
        if self._started:
            self.trigger(self.BEGIN_COURSES_TRIGGER)

    def _all_courses_completed(self) -> bool:
        """Returns False if there's at least one unapproved.
        """
        return len(self._next_academic_period_courses) == 0

    def _update_course_state(self, records: Set[CourseState]):

        report.send_message(
            report.CurriculumGeneralDebugMessage("Update courses records.")
        )

        courses_table = self.flowchart.graph_dict

        for record in records:
            course: Course = courses_table[record.course_id]
            course.fetch_course_state(record)

    def _poll_academic_period_state(self):
        """Request for the courses state and the messages reports to classrooms.

        When all the courses has been processed, this method will
        request the course records to fetch the head curriculum state,
        and finally will invoke COURSES_COMPLETED_TRANSITION transition.
        """
        sleep_interval = 20

        # Classrooms are closed (at least one) they haven't started the processing.
        while not all(
            list(
                map(
                    lambda classroom: ray.get(classroom.get_state.remote())
                    != RayClassroom.STATE_CLOSED,
                    self._next_academic_period_assigned_classrooms,
                )
            )
        ):
            time.sleep(5)  # Wait 5 seconds

        # Classrooms (at least one) are busy processing courses.
        while not all(
            list(
                map(
                    lambda classroom: ray.get(classroom.get_state.remote())
                    != RayClassroom.STATE_BUSY,
                    self._next_academic_period_assigned_classrooms,
                )
            )
        ):
            time.sleep(sleep_interval)

        # Get course state from distributed classrooms.
        states: List[CourseState] = []
        for classroom in self._next_academic_period_assigned_classrooms:
            states += list(ray.get(classroom.get_last_courses_record.remote()))

        # finally, closes the classrooms and puts the back in the pool
        self._close_classrooms()
        report.send_message(
            report.CurriculumGeneralDebugMessage(
                "Classrooms processing completed for academic period."
            )
        )

        self._update_course_state(states)
        self.trigger(self.ASSIGNED_COURSES_COMPLETED_TRIGGER)

    def _close_classrooms(self):
        """Close the current academic period classrooms, and puts them back
        in the pool.
        """
        for course in self._next_academic_period_assigned_classrooms:
            course.close.remote()

        for classroom in self._next_academic_period_assigned_classrooms:
            self.classroom_pool.put_in(classroom)

        self._next_academic_period_assigned_classrooms = []

    def _take_courses(self):
        """This is a wrapper function for course executor
        take_courses method.

        It is configured to be invoked when the curriculum
        makes the transition to ASSIGNED_STATE.

        Right now, the max number of classroom is the max number
        of parallel courses in the same academic period. Given so, it's safe
        to assume that courses and classrooms containers have the same length.
        """
        assigned_courses_classrooms = list(
            zip(
                self._next_academic_period_assigned_classrooms,
                self._next_academic_period_courses,
            )
        )

        # Send courses to remote classrooms
        [
            classroom.take_courses.remote(
                set([course.course_id]), self.package.main_id
            )
            for classroom, course in assigned_courses_classrooms
        ]

        report.send_message(
            report.CurriculumGeneralDebugMessage(
                "Courses scheduled in distributed classrooms."
            )
        )
        polling_thread = threading.Thread(
            target=self._poll_academic_period_state,
            name="poll_multi_classrooms",
        )
        polling_thread.start()

    def _remote_reporting_listener(self):
        """Function to be executed concurrently,
        requesting new messages from the remote reporting.

        TODO: sleep interval between updates should be a config
            value.
        """
        interval = 10

        while True:
            new_messages = ray.get(
                self._mammut_session_context.main_report_actor_handle.get_messages.remote()
            )
            for message in new_messages:
                report.send_message(message)
            time.sleep(interval)

    def load(self):
        """Loads the Curriculum and all the Package information.

        When this method is called, the Curriculum can transition to a
        'ready' state.
        """
        super().load()

        self._remote_reporting_listener_thread = threading.Thread(
            target=self._remote_reporting_listener,
            name="remote_reporting_listener",
            daemon=True,
        )
        self._remote_reporting_listener_thread.start()

        report.send_message(
            report.CurriculumGeneralInfoMessage(
                "Main report registry configured."
            )
        )

        report.send_message(
            report.CurriculumGeneralInfoMessage(
                "Multi classrooms initialization"
            )
        )

        self.classroom_pool = ClassroomPool(
            self.flowchart.get_max_parallel_courses(),
            self.package.main_id,
            self.package.standard_spreadsheet_id,
            self._mammut_session_context,
            self._enable_ktt_interpretation,
            self.package.package_id_is_spreadsheet,
        )

        report.send_message(
            report.CurriculumGeneralInfoMessage("Curriculum load completed.")
        )

        # TODO: transition is called here, but the classrooms will be loading remotely.
        #   that should be considered in some kind of mechanism.
        self.trigger(self.PREPARE_TRIGGER)

    def begin(self):
        """Start the processing of the Curriculum learning.

        Use case: to start all the concurrent/parallel processing
        of lessons.

        The curriculum process will begin from the last checkpoint
        (if exists) or from the curriculum first academic period.

        Preconditions:
            - No Curriculum learning process can be started if the
                curriculum state is different than 'ready'.
        """
        if self.state == self.STATE_READY.name:
            self._started = True
            self.trigger(self.BEGIN_COURSES_TRIGGER)

        else:
            message = "Curriculum isn't in a valid state for begin(). Nothing happens."
            self.errors += message
            report.send_message(
                report.CurriculumGeneralWarningMessage(message)
            )

    def stop(self):
        """Stops the processing of the Curriculum learning.

        Use case: Stop the processing and free the computing
        resources.

        Note: Currently, calling this method does not guarantee the checkpoint
        persistence of the current lessons models being processed.
        """
        if self.state == self.STATE_ASSIGNED.name:
            self.classroom_pool.stop()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: apps/InterpreterMain.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='apps/InterpreterMain.proto',
  package='com.mammut.interpreter',
  syntax='proto3',
  serialized_options=_b('B\025InterpreterMainProtos'),
  serialized_pb=_b('\n\x1a\x61pps/InterpreterMain.proto\x12\x16\x63om.mammut.interpreter\"\xdd\x01\n\x14InterpreterMainInput\x12\x10\n\x08mammutId\x18\x01 \x01(\x03\x12\x0f\n\x07slideId\x18\x02 \x01(\t\x12\x1d\n\x15\x65xecuteSamplingCorpus\x18\x03 \x01(\x08\x12\x11\n\tcorpusIds\x18\x04 \x03(\x05\x12\x1e\n\x16metadataTokenSeparator\x18\x05 \x01(\t\x12\x18\n\x10regionalSettings\x18\x06 \x01(\t\x12\x0e\n\x06userId\x18\x07 \x01(\x03\x12\x0e\n\x06roomId\x18\x08 \x01(\x03\x12\x16\n\x0emammutLoggerId\x18\t \x01(\x03\"\x17\n\x15ImportantMessageProto\"Y\n\x17UnsupportedFeatureProto\x12>\n\x0e\x65rrorComponent\x18\x01 \x01(\x0e\x32&.com.mammut.interpreter.ErrorComponent\"\'\n\x12\x43ompilerPhaseProto\x12\x11\n\textraInfo\x18\x01 \x01(\t\":\n\x15InterpreterPhaseProto\x12\x0e\n\x06roomId\x18\x01 \x01(\x04\x12\x11\n\textraInfo\x18\x02 \x01(\t\"w\n\x1fPropertyDescriptorNotFoundProto\x12\x14\n\x0cpropertyName\x18\x01 \x01(\t\x12>\n\x0e\x65rrorComponent\x18\x02 \x01(\x0e\x32&.com.mammut.interpreter.ErrorComponent\"o\n\x1b\x45\x64geDescriptorNotFoundProto\x12\x10\n\x08\x65\x64geName\x18\x01 \x01(\t\x12>\n\x0e\x65rrorComponent\x18\x02 \x01(\x0e\x32&.com.mammut.interpreter.ErrorComponent\"\x97\x01\n\x1aPropertyValueNotFoundProto\x12\x14\n\x0cpropertyName\x18\x01 \x01(\t\x12\x12\n\nvertexName\x18\x02 \x01(\t\x12\x0f\n\x07sheetId\x18\x03 \x01(\t\x12>\n\x0e\x65rrorComponent\x18\x04 \x01(\x0e\x32&.com.mammut.interpreter.ErrorComponent\"j\n\x16\x45\x64geValueNotFoundProto\x12\x10\n\x08traverse\x18\x01 \x01(\t\x12>\n\x0e\x65rrorComponent\x18\x04 \x01(\x0e\x32&.com.mammut.interpreter.ErrorComponent\"\x85\x01\n\x1aUnknownPropertyOrEdgeProto\x12\x13\n\x0b\x65lementName\x18\x01 \x01(\t\x12\x12\n\nvertexName\x18\x02 \x01(\t\x12>\n\x0e\x65rrorComponent\x18\x03 \x01(\x0e\x32&.com.mammut.interpreter.ErrorComponent\"m\n\x19OntologyTypeNotFoundProto\x12\x10\n\x08typeName\x18\x01 \x01(\t\x12>\n\x0e\x65rrorComponent\x18\x02 \x01(\x0e\x32&.com.mammut.interpreter.ErrorComponent\"\x8b\x01\n\x14VertexUndefinedProto\x12\x11\n\tsrcVertex\x18\x01 \x01(\t\x12\x0f\n\x07srcEdge\x18\x02 \x01(\t\x12\x0f\n\x07sheetId\x18\x03 \x01(\t\x12>\n\x0e\x65rrorComponent\x18\x04 \x01(\x0e\x32&.com.mammut.interpreter.ErrorComponent\"e\n\x12SheetNotFoundProto\x12\x0f\n\x07sheetId\x18\x01 \x01(\t\x12>\n\x0e\x65rrorComponent\x18\x02 \x01(\x0e\x32&.com.mammut.interpreter.ErrorComponent\"r\n\x19ReservedKeywordFoundProto\x12\x15\n\rreserverdWord\x18\x01 \x01(\t\x12>\n\x0e\x65rrorComponent\x18\x02 \x01(\x0e\x32&.com.mammut.interpreter.ErrorComponent\"t\n\x1cUnexpectedCompilerErrorProto\x12\x14\n\x0c\x63\x61useMessage\x18\x01 \x01(\t\x12>\n\x0e\x65rrorComponent\x18\x02 \x01(\x0e\x32&.com.mammut.interpreter.ErrorComponent\"\x85\x01\n\x14ObjectUndefinedProto\x12\x15\n\robjectElement\x18\x01 \x01(\t\x12\x16\n\x0epackageElement\x18\x02 \x01(\t\x12>\n\x0e\x65rrorComponent\x18\x03 \x01(\x0e\x32&.com.mammut.interpreter.ErrorComponent\"x\n\"DefaultVertexPropertyNotFoundProto\x12\x12\n\nvertexName\x18\x01 \x01(\t\x12>\n\x0e\x65rrorComponent\x18\x03 \x01(\x0e\x32&.com.mammut.interpreter.ErrorComponent\"z\n$MultipleDefaultVertexPropertiesProto\x12\x12\n\nvertexName\x18\x01 \x01(\t\x12>\n\x0e\x65rrorComponent\x18\x03 \x01(\x0e\x32&.com.mammut.interpreter.ErrorComponent\"\xad\"\n\x15InterpreterMainOutput\x12\x41\n\x04type\x18\x01 \x01(\x0e\x32\x33.com.mammut.interpreter.InterpreterMainOutput.Types\x12\x15\n\runknownMammut\x18\x02 \x01(\x08\x12\x13\n\x0bunknownRoom\x18\x66 \x01(\x08\x12\x13\n\x0bunknownUser\x18g \x01(\x08\x12\x10\n\x08mammutId\x18\x03 \x01(\x03\x12\x0e\n\x06roomId\x18\x64 \x01(\x03\x12\x0e\n\x06userId\x18\x65 \x01(\x03\x12\x43\n\x05level\x18\x04 \x01(\x0e\x32\x34.com.mammut.interpreter.InterpreterMainOutput.Levels\x12\x0f\n\x07message\x18\x05 \x01(\t\x12\x11\n\tthrowable\x18\x06 \x01(\t\x12\x42\n\x05phase\x18\x07 \x01(\x0e\x32\x33.com.mammut.interpreter.InterpreterMainOutput.Phase\x12\x1b\n\x13\x63orpusCompilationId\x18\x08 \x01(\t\x12L\n\ncorpusType\x18\t \x01(\x0e\x32\x38.com.mammut.interpreter.InterpreterMainOutput.CorpusType\x12I\n\x10importantMessage\x18\n \x01(\x0b\x32-.com.mammut.interpreter.ImportantMessageProtoH\x00\x12M\n\x12unsupportedFeature\x18\x0b \x01(\x0b\x32/.com.mammut.interpreter.UnsupportedFeatureProtoH\x00\x12\x43\n\rcompilerPhase\x18\x0c \x01(\x0b\x32*.com.mammut.interpreter.CompilerPhaseProtoH\x00\x12I\n\x10interpreterPhase\x18\r \x01(\x0b\x32-.com.mammut.interpreter.InterpreterPhaseProtoH\x00\x12S\n\x15propertyValueNotFound\x18\x0f \x01(\x0b\x32\x32.com.mammut.interpreter.PropertyValueNotFoundProtoH\x00\x12K\n\x11\x65\x64geValueNotFound\x18\x10 \x01(\x0b\x32..com.mammut.interpreter.EdgeValueNotFoundProtoH\x00\x12S\n\x15unknownPropertyOrEdge\x18\x11 \x01(\x0b\x32\x32.com.mammut.interpreter.UnknownPropertyOrEdgeProtoH\x00\x12Q\n\x14ontologyTypeNotFound\x18\x12 \x01(\x0b\x32\x31.com.mammut.interpreter.OntologyTypeNotFoundProtoH\x00\x12G\n\x0fvertexUndefined\x18\x13 \x01(\x0b\x32,.com.mammut.interpreter.VertexUndefinedProtoH\x00\x12\x43\n\rsheetNotFound\x18\x16 \x01(\x0b\x32*.com.mammut.interpreter.SheetNotFoundProtoH\x00\x12Q\n\x14reservedKeywordFound\x18\x17 \x01(\x0b\x32\x31.com.mammut.interpreter.ReservedKeywordFoundProtoH\x00\x12]\n\x1apropertyDescriptorNotFound\x18\x18 \x01(\x0b\x32\x37.com.mammut.interpreter.PropertyDescriptorNotFoundProtoH\x00\x12U\n\x16\x65\x64geDescriptorNotFound\x18\x1b \x01(\x0b\x32\x33.com.mammut.interpreter.EdgeDescriptorNotFoundProtoH\x00\x12W\n\x17unexpectedCompilerError\x18\x19 \x01(\x0b\x32\x34.com.mammut.interpreter.UnexpectedCompilerErrorProtoH\x00\x12G\n\x0fobjectUndefined\x18\x1a \x01(\x0b\x32,.com.mammut.interpreter.ObjectUndefinedProtoH\x00\x12h\n\"defaultVertexPropertyNotFoundProto\x18\x1c \x01(\x0b\x32:.com.mammut.interpreter.DefaultVertexPropertyNotFoundProtoH\x00\x12l\n$multipleDefaultVertexPropertiesProto\x18\x1d \x01(\x0b\x32<.com.mammut.interpreter.MultipleDefaultVertexPropertiesProtoH\x00\"\xe0\x0b\n\x05Types\x12\x1a\n\x16ImportantMessageOutput\x10\x00\x12\x1c\n\x18UnsupportedFeatureOutput\x10\x01\x12\x1a\n\x16GettingCorpusMapOutput\x10\x02\x12\x19\n\x15GettingOntologyOutput\x10\x03\x12\x1b\n\x17\x45xpandingOntologyOutput\x10\x04\x12\x1d\n\x19\x43omputingEntryPointOutput\x10\x05\x12\"\n\x1eGettingOntologyInstancesOutput\x10\x06\x12)\n%LoadingInstancesToWorkingMemoryOutput\x10\x07\x12#\n\x1fGeneratingOntologyClassesOutput\x10\x08\x12\x1a\n\x16GettingVariablesOutput\x10\t\x12\x1a\n\x16GettingSceneriesOutput\x10\n\x12\x1b\n\x17GettingExtensionsOutput\x10\x0b\x12\x1c\n\x18\x43ompilingVariablesOutput\x10\x0c\x12\x1c\n\x18\x43ompilingSceneriesOutput\x10\r\x12\x1d\n\x19\x43ompilingExtensionsOutput\x10\x0e\x12$\n GroupingCompiledExtensionsOutput\x10\x0f\x12#\n\x1fGroupingCompiledSceneriesOutput\x10\x10\x12$\n CompilingInformationTuplesOutput\x10\x11\x12\x16\n\x12StartPlayingOutput\x10\x12\x12!\n\x1dUnpreparedMammutDetectedOuput\x10\x13\x12\'\n#ResolvingMissingIterableIndexOutput\x10\x14\x12\"\n\x1eResolvingMissingVertexIdOutput\x10\x15\x12\x31\n-ResolvingMissingVertexIdForSetOperationOutput\x10\x16\x12(\n$ResolvingOverrideValueConflictOutput\x10\x17\x12\x1c\n\x18LtBBInterpretationOutput\x10\x18\x12$\n LtBBDesambiguatorExpansionOutput\x10\x19\x12\x18\n\x14\x41tCTGenerationOutput\x10\x1a\x12#\n\x1f\x41tCTDesambiguatorChoosingOutput\x10\x1b\x12#\n\x1fGettingIssueChannelOutputOutput\x10\x1c\x12\x1c\n\x18GettingThinkStatusOutput\x10\x1d\x12\x1f\n\x1bPropertyValueNotFoundOutput\x10\x1f\x12\x1f\n\x1bUnknownPropertyOrEdgeOutput\x10 \x12\x1e\n\x1aOntologyTypeNotFoundOutput\x10!\x12\x19\n\x15VertexUndefinedOutput\x10\"\x12\x1b\n\x17VariableUndefinedOutput\x10#\x12\x18\n\x14\x46ieldUndefinedOutput\x10$\x12\x1b\n\x17\x45\x64geValueNotFoundOutput\x10%\x12\x11\n\rSuccessOutput\x10&\x12\x11\n\rFailureOutput\x10\'\x12\x11\n\rSheetNotFound\x10(\x12\x1e\n\x1aReservedKeywordFoundOutput\x10)\x12$\n PropertyDescriptorNotFoundOutput\x10*\x12\x1a\n\x16\x45\x64geDescriptorNotFound\x10\x34\x12\x1b\n\x17UnexpectedCompilerError\x10\x32\x12\x19\n\x15ObjectUndefinedOutput\x10\x33\x12!\n\x1d\x44\x65\x66\x61ultVertexPropertyNotFound\x10\x37\x12#\n\x1fMultipleDefaultVertexProperties\x10\x38\"O\n\x06Levels\x12\x07\n\x03\x41ll\x10\x00\x12\t\n\x05Trace\x10\x01\x12\t\n\x05\x44\x65\x62ug\x10\x02\x12\x08\n\x04Info\x10\x03\x12\x08\n\x04Warn\x10\x04\x12\t\n\x05\x45rror\x10\x05\x12\x07\n\x03Off\x10\x06\"\xa5\x06\n\x05Phase\x12\x10\n\x0cWithoutPhase\x10\x00\x12\x14\n\x10GettingCorpusMap\x10\x01\x12\x13\n\x0fGettingOntology\x10\x02\x12\x15\n\x11\x45xpandingOntology\x10\x03\x12\x17\n\x13\x43omputingEntrypoint\x10\x04\x12\x1c\n\x18GettingOntologyInstances\x10\x05\x12#\n\x1fLoadingInstancesToWorkingMemory\x10\x06\x12\x1d\n\x19GeneratingOntologyClasses\x10\x07\x12\x14\n\x10GettingVariables\x10\x08\x12\x14\n\x10GettingSceneries\x10\t\x12\x15\n\x11GettingExtensions\x10\n\x12\x16\n\x12\x43ompilingVariables\x10\x0b\x12\x16\n\x12\x43ompilingSceneries\x10\x0c\x12\x17\n\x13\x43ompilingExtensions\x10\r\x12\x1e\n\x1aGroupingCompiledExtensions\x10\x0e\x12\x1d\n\x19GroupingCompiledSceneries\x10\x0f\x12\x1e\n\x1a\x43ompilingInformationTuples\x10\x10\x12\x10\n\x0cStartPlaying\x10\x1e\x12\x1c\n\x18UnpreparedMammutDetected\x10\x1f\x12!\n\x1dResolvingMissingIterableIndex\x10 \x12\x1c\n\x18ResolvingMissingVertexId\x10!\x12+\n\'ResolvingMissingVertexIdForSetOperation\x10\"\x12\"\n\x1eResolvingOverrideValueConflict\x10#\x12\x16\n\x12LtBBInterpretation\x10$\x12\x1e\n\x1aLtBBDesambiguatorExpansion\x10%\x12\x12\n\x0e\x41tCTGeneration\x10&\x12\x1d\n\x19\x41tCTDesambiguatorChoosing\x10\'\x12\x1d\n\x19GettingIssueChannelOutput\x10(\x12\x16\n\x12GettingThinkStatus\x10)\"T\n\nCorpusType\x12\x15\n\x11WithoutCorpusType\x10\x00\x12\n\n\x06Mammut\x10\x01\x12\x0b\n\x07\x43rawler\x10\x02\x12\x0b\n\x07Natural\x10\x03\x12\t\n\x05Issue\x10\x04\x42\x0f\n\rmessage_oneof*\x91\x01\n\x0e\x45rrorComponent\x12\x0f\n\x0bKttCompiler\x10\x00\x12\x17\n\x13KttConversationtime\x10\x01\x12\r\n\tKttMemory\x10\x02\x12\x0f\n\x0bKttOntology\x10\x03\x12\x12\n\x0eKttInterpreter\x10\x04\x12\x14\n\x10KttGoogleStorage\x10\x05\x12\x0b\n\x07KttRoot\x10\x06\x42\x17\x42\x15InterpreterMainProtosb\x06proto3')
)

_ERRORCOMPONENT = _descriptor.EnumDescriptor(
  name='ErrorComponent',
  full_name='com.mammut.interpreter.ErrorComponent',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='KttCompiler', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KttConversationtime', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KttMemory', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KttOntology', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KttInterpreter', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KttGoogleStorage', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KttRoot', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6500,
  serialized_end=6645,
)
_sym_db.RegisterEnumDescriptor(_ERRORCOMPONENT)

ErrorComponent = enum_type_wrapper.EnumTypeWrapper(_ERRORCOMPONENT)
KttCompiler = 0
KttConversationtime = 1
KttMemory = 2
KttOntology = 3
KttInterpreter = 4
KttGoogleStorage = 5
KttRoot = 6


_INTERPRETERMAINOUTPUT_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='com.mammut.interpreter.InterpreterMainOutput.Types',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ImportantMessageOutput', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnsupportedFeatureOutput', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GettingCorpusMapOutput', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GettingOntologyOutput', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExpandingOntologyOutput', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ComputingEntryPointOutput', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GettingOntologyInstancesOutput', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LoadingInstancesToWorkingMemoryOutput', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GeneratingOntologyClassesOutput', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GettingVariablesOutput', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GettingSceneriesOutput', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GettingExtensionsOutput', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CompilingVariablesOutput', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CompilingSceneriesOutput', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CompilingExtensionsOutput', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GroupingCompiledExtensionsOutput', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GroupingCompiledSceneriesOutput', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CompilingInformationTuplesOutput', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='StartPlayingOutput', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnpreparedMammutDetectedOuput', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ResolvingMissingIterableIndexOutput', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ResolvingMissingVertexIdOutput', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ResolvingMissingVertexIdForSetOperationOutput', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ResolvingOverrideValueConflictOutput', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LtBBInterpretationOutput', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LtBBDesambiguatorExpansionOutput', index=25, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AtCTGenerationOutput', index=26, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AtCTDesambiguatorChoosingOutput', index=27, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GettingIssueChannelOutputOutput', index=28, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GettingThinkStatusOutput', index=29, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PropertyValueNotFoundOutput', index=30, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnknownPropertyOrEdgeOutput', index=31, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OntologyTypeNotFoundOutput', index=32, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VertexUndefinedOutput', index=33, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VariableUndefinedOutput', index=34, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FieldUndefinedOutput', index=35, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EdgeValueNotFoundOutput', index=36, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SuccessOutput', index=37, number=38,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FailureOutput', index=38, number=39,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SheetNotFound', index=39, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ReservedKeywordFoundOutput', index=40, number=41,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PropertyDescriptorNotFoundOutput', index=41, number=42,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EdgeDescriptorNotFound', index=42, number=52,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnexpectedCompilerError', index=43, number=50,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ObjectUndefinedOutput', index=44, number=51,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DefaultVertexPropertyNotFound', index=45, number=55,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MultipleDefaultVertexProperties', index=46, number=56,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4001,
  serialized_end=5505,
)
_sym_db.RegisterEnumDescriptor(_INTERPRETERMAINOUTPUT_TYPES)

_INTERPRETERMAINOUTPUT_LEVELS = _descriptor.EnumDescriptor(
  name='Levels',
  full_name='com.mammut.interpreter.InterpreterMainOutput.Levels',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='All', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Trace', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Debug', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Info', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Warn', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Error', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Off', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5507,
  serialized_end=5586,
)
_sym_db.RegisterEnumDescriptor(_INTERPRETERMAINOUTPUT_LEVELS)

_INTERPRETERMAINOUTPUT_PHASE = _descriptor.EnumDescriptor(
  name='Phase',
  full_name='com.mammut.interpreter.InterpreterMainOutput.Phase',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WithoutPhase', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GettingCorpusMap', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GettingOntology', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExpandingOntology', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ComputingEntrypoint', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GettingOntologyInstances', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LoadingInstancesToWorkingMemory', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GeneratingOntologyClasses', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GettingVariables', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GettingSceneries', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GettingExtensions', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CompilingVariables', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CompilingSceneries', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CompilingExtensions', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GroupingCompiledExtensions', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GroupingCompiledSceneries', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CompilingInformationTuples', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='StartPlaying', index=17, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnpreparedMammutDetected', index=18, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ResolvingMissingIterableIndex', index=19, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ResolvingMissingVertexId', index=20, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ResolvingMissingVertexIdForSetOperation', index=21, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ResolvingOverrideValueConflict', index=22, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LtBBInterpretation', index=23, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LtBBDesambiguatorExpansion', index=24, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AtCTGeneration', index=25, number=38,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AtCTDesambiguatorChoosing', index=26, number=39,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GettingIssueChannelOutput', index=27, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GettingThinkStatus', index=28, number=41,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5589,
  serialized_end=6394,
)
_sym_db.RegisterEnumDescriptor(_INTERPRETERMAINOUTPUT_PHASE)

_INTERPRETERMAINOUTPUT_CORPUSTYPE = _descriptor.EnumDescriptor(
  name='CorpusType',
  full_name='com.mammut.interpreter.InterpreterMainOutput.CorpusType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WithoutCorpusType', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Mammut', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Crawler', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Natural', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Issue', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6396,
  serialized_end=6480,
)
_sym_db.RegisterEnumDescriptor(_INTERPRETERMAINOUTPUT_CORPUSTYPE)


_INTERPRETERMAININPUT = _descriptor.Descriptor(
  name='InterpreterMainInput',
  full_name='com.mammut.interpreter.InterpreterMainInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mammutId', full_name='com.mammut.interpreter.InterpreterMainInput.mammutId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slideId', full_name='com.mammut.interpreter.InterpreterMainInput.slideId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='executeSamplingCorpus', full_name='com.mammut.interpreter.InterpreterMainInput.executeSamplingCorpus', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='corpusIds', full_name='com.mammut.interpreter.InterpreterMainInput.corpusIds', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadataTokenSeparator', full_name='com.mammut.interpreter.InterpreterMainInput.metadataTokenSeparator', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='regionalSettings', full_name='com.mammut.interpreter.InterpreterMainInput.regionalSettings', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userId', full_name='com.mammut.interpreter.InterpreterMainInput.userId', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='roomId', full_name='com.mammut.interpreter.InterpreterMainInput.roomId', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mammutLoggerId', full_name='com.mammut.interpreter.InterpreterMainInput.mammutLoggerId', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=276,
)


_IMPORTANTMESSAGEPROTO = _descriptor.Descriptor(
  name='ImportantMessageProto',
  full_name='com.mammut.interpreter.ImportantMessageProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=278,
  serialized_end=301,
)


_UNSUPPORTEDFEATUREPROTO = _descriptor.Descriptor(
  name='UnsupportedFeatureProto',
  full_name='com.mammut.interpreter.UnsupportedFeatureProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='errorComponent', full_name='com.mammut.interpreter.UnsupportedFeatureProto.errorComponent', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=392,
)


_COMPILERPHASEPROTO = _descriptor.Descriptor(
  name='CompilerPhaseProto',
  full_name='com.mammut.interpreter.CompilerPhaseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='extraInfo', full_name='com.mammut.interpreter.CompilerPhaseProto.extraInfo', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=394,
  serialized_end=433,
)


_INTERPRETERPHASEPROTO = _descriptor.Descriptor(
  name='InterpreterPhaseProto',
  full_name='com.mammut.interpreter.InterpreterPhaseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='roomId', full_name='com.mammut.interpreter.InterpreterPhaseProto.roomId', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extraInfo', full_name='com.mammut.interpreter.InterpreterPhaseProto.extraInfo', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=435,
  serialized_end=493,
)


_PROPERTYDESCRIPTORNOTFOUNDPROTO = _descriptor.Descriptor(
  name='PropertyDescriptorNotFoundProto',
  full_name='com.mammut.interpreter.PropertyDescriptorNotFoundProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='propertyName', full_name='com.mammut.interpreter.PropertyDescriptorNotFoundProto.propertyName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorComponent', full_name='com.mammut.interpreter.PropertyDescriptorNotFoundProto.errorComponent', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=495,
  serialized_end=614,
)


_EDGEDESCRIPTORNOTFOUNDPROTO = _descriptor.Descriptor(
  name='EdgeDescriptorNotFoundProto',
  full_name='com.mammut.interpreter.EdgeDescriptorNotFoundProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='edgeName', full_name='com.mammut.interpreter.EdgeDescriptorNotFoundProto.edgeName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorComponent', full_name='com.mammut.interpreter.EdgeDescriptorNotFoundProto.errorComponent', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=727,
)


_PROPERTYVALUENOTFOUNDPROTO = _descriptor.Descriptor(
  name='PropertyValueNotFoundProto',
  full_name='com.mammut.interpreter.PropertyValueNotFoundProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='propertyName', full_name='com.mammut.interpreter.PropertyValueNotFoundProto.propertyName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertexName', full_name='com.mammut.interpreter.PropertyValueNotFoundProto.vertexName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sheetId', full_name='com.mammut.interpreter.PropertyValueNotFoundProto.sheetId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorComponent', full_name='com.mammut.interpreter.PropertyValueNotFoundProto.errorComponent', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=730,
  serialized_end=881,
)


_EDGEVALUENOTFOUNDPROTO = _descriptor.Descriptor(
  name='EdgeValueNotFoundProto',
  full_name='com.mammut.interpreter.EdgeValueNotFoundProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='traverse', full_name='com.mammut.interpreter.EdgeValueNotFoundProto.traverse', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorComponent', full_name='com.mammut.interpreter.EdgeValueNotFoundProto.errorComponent', index=1,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=883,
  serialized_end=989,
)


_UNKNOWNPROPERTYOREDGEPROTO = _descriptor.Descriptor(
  name='UnknownPropertyOrEdgeProto',
  full_name='com.mammut.interpreter.UnknownPropertyOrEdgeProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='elementName', full_name='com.mammut.interpreter.UnknownPropertyOrEdgeProto.elementName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertexName', full_name='com.mammut.interpreter.UnknownPropertyOrEdgeProto.vertexName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorComponent', full_name='com.mammut.interpreter.UnknownPropertyOrEdgeProto.errorComponent', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=992,
  serialized_end=1125,
)


_ONTOLOGYTYPENOTFOUNDPROTO = _descriptor.Descriptor(
  name='OntologyTypeNotFoundProto',
  full_name='com.mammut.interpreter.OntologyTypeNotFoundProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='typeName', full_name='com.mammut.interpreter.OntologyTypeNotFoundProto.typeName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorComponent', full_name='com.mammut.interpreter.OntologyTypeNotFoundProto.errorComponent', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1127,
  serialized_end=1236,
)


_VERTEXUNDEFINEDPROTO = _descriptor.Descriptor(
  name='VertexUndefinedProto',
  full_name='com.mammut.interpreter.VertexUndefinedProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='srcVertex', full_name='com.mammut.interpreter.VertexUndefinedProto.srcVertex', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='srcEdge', full_name='com.mammut.interpreter.VertexUndefinedProto.srcEdge', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sheetId', full_name='com.mammut.interpreter.VertexUndefinedProto.sheetId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorComponent', full_name='com.mammut.interpreter.VertexUndefinedProto.errorComponent', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1239,
  serialized_end=1378,
)


_SHEETNOTFOUNDPROTO = _descriptor.Descriptor(
  name='SheetNotFoundProto',
  full_name='com.mammut.interpreter.SheetNotFoundProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sheetId', full_name='com.mammut.interpreter.SheetNotFoundProto.sheetId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorComponent', full_name='com.mammut.interpreter.SheetNotFoundProto.errorComponent', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1380,
  serialized_end=1481,
)


_RESERVEDKEYWORDFOUNDPROTO = _descriptor.Descriptor(
  name='ReservedKeywordFoundProto',
  full_name='com.mammut.interpreter.ReservedKeywordFoundProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reserverdWord', full_name='com.mammut.interpreter.ReservedKeywordFoundProto.reserverdWord', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorComponent', full_name='com.mammut.interpreter.ReservedKeywordFoundProto.errorComponent', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1483,
  serialized_end=1597,
)


_UNEXPECTEDCOMPILERERRORPROTO = _descriptor.Descriptor(
  name='UnexpectedCompilerErrorProto',
  full_name='com.mammut.interpreter.UnexpectedCompilerErrorProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='causeMessage', full_name='com.mammut.interpreter.UnexpectedCompilerErrorProto.causeMessage', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorComponent', full_name='com.mammut.interpreter.UnexpectedCompilerErrorProto.errorComponent', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1599,
  serialized_end=1715,
)


_OBJECTUNDEFINEDPROTO = _descriptor.Descriptor(
  name='ObjectUndefinedProto',
  full_name='com.mammut.interpreter.ObjectUndefinedProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objectElement', full_name='com.mammut.interpreter.ObjectUndefinedProto.objectElement', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packageElement', full_name='com.mammut.interpreter.ObjectUndefinedProto.packageElement', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorComponent', full_name='com.mammut.interpreter.ObjectUndefinedProto.errorComponent', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1718,
  serialized_end=1851,
)


_DEFAULTVERTEXPROPERTYNOTFOUNDPROTO = _descriptor.Descriptor(
  name='DefaultVertexPropertyNotFoundProto',
  full_name='com.mammut.interpreter.DefaultVertexPropertyNotFoundProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vertexName', full_name='com.mammut.interpreter.DefaultVertexPropertyNotFoundProto.vertexName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorComponent', full_name='com.mammut.interpreter.DefaultVertexPropertyNotFoundProto.errorComponent', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1853,
  serialized_end=1973,
)


_MULTIPLEDEFAULTVERTEXPROPERTIESPROTO = _descriptor.Descriptor(
  name='MultipleDefaultVertexPropertiesProto',
  full_name='com.mammut.interpreter.MultipleDefaultVertexPropertiesProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vertexName', full_name='com.mammut.interpreter.MultipleDefaultVertexPropertiesProto.vertexName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorComponent', full_name='com.mammut.interpreter.MultipleDefaultVertexPropertiesProto.errorComponent', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1975,
  serialized_end=2097,
)


_INTERPRETERMAINOUTPUT = _descriptor.Descriptor(
  name='InterpreterMainOutput',
  full_name='com.mammut.interpreter.InterpreterMainOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='com.mammut.interpreter.InterpreterMainOutput.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unknownMammut', full_name='com.mammut.interpreter.InterpreterMainOutput.unknownMammut', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unknownRoom', full_name='com.mammut.interpreter.InterpreterMainOutput.unknownRoom', index=2,
      number=102, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unknownUser', full_name='com.mammut.interpreter.InterpreterMainOutput.unknownUser', index=3,
      number=103, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mammutId', full_name='com.mammut.interpreter.InterpreterMainOutput.mammutId', index=4,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='roomId', full_name='com.mammut.interpreter.InterpreterMainOutput.roomId', index=5,
      number=100, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userId', full_name='com.mammut.interpreter.InterpreterMainOutput.userId', index=6,
      number=101, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='com.mammut.interpreter.InterpreterMainOutput.level', index=7,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.mammut.interpreter.InterpreterMainOutput.message', index=8,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='throwable', full_name='com.mammut.interpreter.InterpreterMainOutput.throwable', index=9,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phase', full_name='com.mammut.interpreter.InterpreterMainOutput.phase', index=10,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='corpusCompilationId', full_name='com.mammut.interpreter.InterpreterMainOutput.corpusCompilationId', index=11,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='corpusType', full_name='com.mammut.interpreter.InterpreterMainOutput.corpusType', index=12,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='importantMessage', full_name='com.mammut.interpreter.InterpreterMainOutput.importantMessage', index=13,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unsupportedFeature', full_name='com.mammut.interpreter.InterpreterMainOutput.unsupportedFeature', index=14,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compilerPhase', full_name='com.mammut.interpreter.InterpreterMainOutput.compilerPhase', index=15,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interpreterPhase', full_name='com.mammut.interpreter.InterpreterMainOutput.interpreterPhase', index=16,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='propertyValueNotFound', full_name='com.mammut.interpreter.InterpreterMainOutput.propertyValueNotFound', index=17,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='edgeValueNotFound', full_name='com.mammut.interpreter.InterpreterMainOutput.edgeValueNotFound', index=18,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unknownPropertyOrEdge', full_name='com.mammut.interpreter.InterpreterMainOutput.unknownPropertyOrEdge', index=19,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ontologyTypeNotFound', full_name='com.mammut.interpreter.InterpreterMainOutput.ontologyTypeNotFound', index=20,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertexUndefined', full_name='com.mammut.interpreter.InterpreterMainOutput.vertexUndefined', index=21,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sheetNotFound', full_name='com.mammut.interpreter.InterpreterMainOutput.sheetNotFound', index=22,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reservedKeywordFound', full_name='com.mammut.interpreter.InterpreterMainOutput.reservedKeywordFound', index=23,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='propertyDescriptorNotFound', full_name='com.mammut.interpreter.InterpreterMainOutput.propertyDescriptorNotFound', index=24,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='edgeDescriptorNotFound', full_name='com.mammut.interpreter.InterpreterMainOutput.edgeDescriptorNotFound', index=25,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unexpectedCompilerError', full_name='com.mammut.interpreter.InterpreterMainOutput.unexpectedCompilerError', index=26,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectUndefined', full_name='com.mammut.interpreter.InterpreterMainOutput.objectUndefined', index=27,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defaultVertexPropertyNotFoundProto', full_name='com.mammut.interpreter.InterpreterMainOutput.defaultVertexPropertyNotFoundProto', index=28,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='multipleDefaultVertexPropertiesProto', full_name='com.mammut.interpreter.InterpreterMainOutput.multipleDefaultVertexPropertiesProto', index=29,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INTERPRETERMAINOUTPUT_TYPES,
    _INTERPRETERMAINOUTPUT_LEVELS,
    _INTERPRETERMAINOUTPUT_PHASE,
    _INTERPRETERMAINOUTPUT_CORPUSTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message_oneof', full_name='com.mammut.interpreter.InterpreterMainOutput.message_oneof',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2100,
  serialized_end=6497,
)

_UNSUPPORTEDFEATUREPROTO.fields_by_name['errorComponent'].enum_type = _ERRORCOMPONENT
_PROPERTYDESCRIPTORNOTFOUNDPROTO.fields_by_name['errorComponent'].enum_type = _ERRORCOMPONENT
_EDGEDESCRIPTORNOTFOUNDPROTO.fields_by_name['errorComponent'].enum_type = _ERRORCOMPONENT
_PROPERTYVALUENOTFOUNDPROTO.fields_by_name['errorComponent'].enum_type = _ERRORCOMPONENT
_EDGEVALUENOTFOUNDPROTO.fields_by_name['errorComponent'].enum_type = _ERRORCOMPONENT
_UNKNOWNPROPERTYOREDGEPROTO.fields_by_name['errorComponent'].enum_type = _ERRORCOMPONENT
_ONTOLOGYTYPENOTFOUNDPROTO.fields_by_name['errorComponent'].enum_type = _ERRORCOMPONENT
_VERTEXUNDEFINEDPROTO.fields_by_name['errorComponent'].enum_type = _ERRORCOMPONENT
_SHEETNOTFOUNDPROTO.fields_by_name['errorComponent'].enum_type = _ERRORCOMPONENT
_RESERVEDKEYWORDFOUNDPROTO.fields_by_name['errorComponent'].enum_type = _ERRORCOMPONENT
_UNEXPECTEDCOMPILERERRORPROTO.fields_by_name['errorComponent'].enum_type = _ERRORCOMPONENT
_OBJECTUNDEFINEDPROTO.fields_by_name['errorComponent'].enum_type = _ERRORCOMPONENT
_DEFAULTVERTEXPROPERTYNOTFOUNDPROTO.fields_by_name['errorComponent'].enum_type = _ERRORCOMPONENT
_MULTIPLEDEFAULTVERTEXPROPERTIESPROTO.fields_by_name['errorComponent'].enum_type = _ERRORCOMPONENT
_INTERPRETERMAINOUTPUT.fields_by_name['type'].enum_type = _INTERPRETERMAINOUTPUT_TYPES
_INTERPRETERMAINOUTPUT.fields_by_name['level'].enum_type = _INTERPRETERMAINOUTPUT_LEVELS
_INTERPRETERMAINOUTPUT.fields_by_name['phase'].enum_type = _INTERPRETERMAINOUTPUT_PHASE
_INTERPRETERMAINOUTPUT.fields_by_name['corpusType'].enum_type = _INTERPRETERMAINOUTPUT_CORPUSTYPE
_INTERPRETERMAINOUTPUT.fields_by_name['importantMessage'].message_type = _IMPORTANTMESSAGEPROTO
_INTERPRETERMAINOUTPUT.fields_by_name['unsupportedFeature'].message_type = _UNSUPPORTEDFEATUREPROTO
_INTERPRETERMAINOUTPUT.fields_by_name['compilerPhase'].message_type = _COMPILERPHASEPROTO
_INTERPRETERMAINOUTPUT.fields_by_name['interpreterPhase'].message_type = _INTERPRETERPHASEPROTO
_INTERPRETERMAINOUTPUT.fields_by_name['propertyValueNotFound'].message_type = _PROPERTYVALUENOTFOUNDPROTO
_INTERPRETERMAINOUTPUT.fields_by_name['edgeValueNotFound'].message_type = _EDGEVALUENOTFOUNDPROTO
_INTERPRETERMAINOUTPUT.fields_by_name['unknownPropertyOrEdge'].message_type = _UNKNOWNPROPERTYOREDGEPROTO
_INTERPRETERMAINOUTPUT.fields_by_name['ontologyTypeNotFound'].message_type = _ONTOLOGYTYPENOTFOUNDPROTO
_INTERPRETERMAINOUTPUT.fields_by_name['vertexUndefined'].message_type = _VERTEXUNDEFINEDPROTO
_INTERPRETERMAINOUTPUT.fields_by_name['sheetNotFound'].message_type = _SHEETNOTFOUNDPROTO
_INTERPRETERMAINOUTPUT.fields_by_name['reservedKeywordFound'].message_type = _RESERVEDKEYWORDFOUNDPROTO
_INTERPRETERMAINOUTPUT.fields_by_name['propertyDescriptorNotFound'].message_type = _PROPERTYDESCRIPTORNOTFOUNDPROTO
_INTERPRETERMAINOUTPUT.fields_by_name['edgeDescriptorNotFound'].message_type = _EDGEDESCRIPTORNOTFOUNDPROTO
_INTERPRETERMAINOUTPUT.fields_by_name['unexpectedCompilerError'].message_type = _UNEXPECTEDCOMPILERERRORPROTO
_INTERPRETERMAINOUTPUT.fields_by_name['objectUndefined'].message_type = _OBJECTUNDEFINEDPROTO
_INTERPRETERMAINOUTPUT.fields_by_name['defaultVertexPropertyNotFoundProto'].message_type = _DEFAULTVERTEXPROPERTYNOTFOUNDPROTO
_INTERPRETERMAINOUTPUT.fields_by_name['multipleDefaultVertexPropertiesProto'].message_type = _MULTIPLEDEFAULTVERTEXPROPERTIESPROTO
_INTERPRETERMAINOUTPUT_TYPES.containing_type = _INTERPRETERMAINOUTPUT
_INTERPRETERMAINOUTPUT_LEVELS.containing_type = _INTERPRETERMAINOUTPUT
_INTERPRETERMAINOUTPUT_PHASE.containing_type = _INTERPRETERMAINOUTPUT
_INTERPRETERMAINOUTPUT_CORPUSTYPE.containing_type = _INTERPRETERMAINOUTPUT
_INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof'].fields.append(
  _INTERPRETERMAINOUTPUT.fields_by_name['importantMessage'])
_INTERPRETERMAINOUTPUT.fields_by_name['importantMessage'].containing_oneof = _INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof']
_INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof'].fields.append(
  _INTERPRETERMAINOUTPUT.fields_by_name['unsupportedFeature'])
_INTERPRETERMAINOUTPUT.fields_by_name['unsupportedFeature'].containing_oneof = _INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof']
_INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof'].fields.append(
  _INTERPRETERMAINOUTPUT.fields_by_name['compilerPhase'])
_INTERPRETERMAINOUTPUT.fields_by_name['compilerPhase'].containing_oneof = _INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof']
_INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof'].fields.append(
  _INTERPRETERMAINOUTPUT.fields_by_name['interpreterPhase'])
_INTERPRETERMAINOUTPUT.fields_by_name['interpreterPhase'].containing_oneof = _INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof']
_INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof'].fields.append(
  _INTERPRETERMAINOUTPUT.fields_by_name['propertyValueNotFound'])
_INTERPRETERMAINOUTPUT.fields_by_name['propertyValueNotFound'].containing_oneof = _INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof']
_INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof'].fields.append(
  _INTERPRETERMAINOUTPUT.fields_by_name['edgeValueNotFound'])
_INTERPRETERMAINOUTPUT.fields_by_name['edgeValueNotFound'].containing_oneof = _INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof']
_INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof'].fields.append(
  _INTERPRETERMAINOUTPUT.fields_by_name['unknownPropertyOrEdge'])
_INTERPRETERMAINOUTPUT.fields_by_name['unknownPropertyOrEdge'].containing_oneof = _INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof']
_INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof'].fields.append(
  _INTERPRETERMAINOUTPUT.fields_by_name['ontologyTypeNotFound'])
_INTERPRETERMAINOUTPUT.fields_by_name['ontologyTypeNotFound'].containing_oneof = _INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof']
_INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof'].fields.append(
  _INTERPRETERMAINOUTPUT.fields_by_name['vertexUndefined'])
_INTERPRETERMAINOUTPUT.fields_by_name['vertexUndefined'].containing_oneof = _INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof']
_INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof'].fields.append(
  _INTERPRETERMAINOUTPUT.fields_by_name['sheetNotFound'])
_INTERPRETERMAINOUTPUT.fields_by_name['sheetNotFound'].containing_oneof = _INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof']
_INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof'].fields.append(
  _INTERPRETERMAINOUTPUT.fields_by_name['reservedKeywordFound'])
_INTERPRETERMAINOUTPUT.fields_by_name['reservedKeywordFound'].containing_oneof = _INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof']
_INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof'].fields.append(
  _INTERPRETERMAINOUTPUT.fields_by_name['propertyDescriptorNotFound'])
_INTERPRETERMAINOUTPUT.fields_by_name['propertyDescriptorNotFound'].containing_oneof = _INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof']
_INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof'].fields.append(
  _INTERPRETERMAINOUTPUT.fields_by_name['edgeDescriptorNotFound'])
_INTERPRETERMAINOUTPUT.fields_by_name['edgeDescriptorNotFound'].containing_oneof = _INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof']
_INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof'].fields.append(
  _INTERPRETERMAINOUTPUT.fields_by_name['unexpectedCompilerError'])
_INTERPRETERMAINOUTPUT.fields_by_name['unexpectedCompilerError'].containing_oneof = _INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof']
_INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof'].fields.append(
  _INTERPRETERMAINOUTPUT.fields_by_name['objectUndefined'])
_INTERPRETERMAINOUTPUT.fields_by_name['objectUndefined'].containing_oneof = _INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof']
_INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof'].fields.append(
  _INTERPRETERMAINOUTPUT.fields_by_name['defaultVertexPropertyNotFoundProto'])
_INTERPRETERMAINOUTPUT.fields_by_name['defaultVertexPropertyNotFoundProto'].containing_oneof = _INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof']
_INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof'].fields.append(
  _INTERPRETERMAINOUTPUT.fields_by_name['multipleDefaultVertexPropertiesProto'])
_INTERPRETERMAINOUTPUT.fields_by_name['multipleDefaultVertexPropertiesProto'].containing_oneof = _INTERPRETERMAINOUTPUT.oneofs_by_name['message_oneof']
DESCRIPTOR.message_types_by_name['InterpreterMainInput'] = _INTERPRETERMAININPUT
DESCRIPTOR.message_types_by_name['ImportantMessageProto'] = _IMPORTANTMESSAGEPROTO
DESCRIPTOR.message_types_by_name['UnsupportedFeatureProto'] = _UNSUPPORTEDFEATUREPROTO
DESCRIPTOR.message_types_by_name['CompilerPhaseProto'] = _COMPILERPHASEPROTO
DESCRIPTOR.message_types_by_name['InterpreterPhaseProto'] = _INTERPRETERPHASEPROTO
DESCRIPTOR.message_types_by_name['PropertyDescriptorNotFoundProto'] = _PROPERTYDESCRIPTORNOTFOUNDPROTO
DESCRIPTOR.message_types_by_name['EdgeDescriptorNotFoundProto'] = _EDGEDESCRIPTORNOTFOUNDPROTO
DESCRIPTOR.message_types_by_name['PropertyValueNotFoundProto'] = _PROPERTYVALUENOTFOUNDPROTO
DESCRIPTOR.message_types_by_name['EdgeValueNotFoundProto'] = _EDGEVALUENOTFOUNDPROTO
DESCRIPTOR.message_types_by_name['UnknownPropertyOrEdgeProto'] = _UNKNOWNPROPERTYOREDGEPROTO
DESCRIPTOR.message_types_by_name['OntologyTypeNotFoundProto'] = _ONTOLOGYTYPENOTFOUNDPROTO
DESCRIPTOR.message_types_by_name['VertexUndefinedProto'] = _VERTEXUNDEFINEDPROTO
DESCRIPTOR.message_types_by_name['SheetNotFoundProto'] = _SHEETNOTFOUNDPROTO
DESCRIPTOR.message_types_by_name['ReservedKeywordFoundProto'] = _RESERVEDKEYWORDFOUNDPROTO
DESCRIPTOR.message_types_by_name['UnexpectedCompilerErrorProto'] = _UNEXPECTEDCOMPILERERRORPROTO
DESCRIPTOR.message_types_by_name['ObjectUndefinedProto'] = _OBJECTUNDEFINEDPROTO
DESCRIPTOR.message_types_by_name['DefaultVertexPropertyNotFoundProto'] = _DEFAULTVERTEXPROPERTYNOTFOUNDPROTO
DESCRIPTOR.message_types_by_name['MultipleDefaultVertexPropertiesProto'] = _MULTIPLEDEFAULTVERTEXPROPERTIESPROTO
DESCRIPTOR.message_types_by_name['InterpreterMainOutput'] = _INTERPRETERMAINOUTPUT
DESCRIPTOR.enum_types_by_name['ErrorComponent'] = _ERRORCOMPONENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InterpreterMainInput = _reflection.GeneratedProtocolMessageType('InterpreterMainInput', (_message.Message,), {
  'DESCRIPTOR' : _INTERPRETERMAININPUT,
  '__module__' : 'apps.InterpreterMain_pb2'
  # @@protoc_insertion_point(class_scope:com.mammut.interpreter.InterpreterMainInput)
  })
_sym_db.RegisterMessage(InterpreterMainInput)

ImportantMessageProto = _reflection.GeneratedProtocolMessageType('ImportantMessageProto', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTANTMESSAGEPROTO,
  '__module__' : 'apps.InterpreterMain_pb2'
  # @@protoc_insertion_point(class_scope:com.mammut.interpreter.ImportantMessageProto)
  })
_sym_db.RegisterMessage(ImportantMessageProto)

UnsupportedFeatureProto = _reflection.GeneratedProtocolMessageType('UnsupportedFeatureProto', (_message.Message,), {
  'DESCRIPTOR' : _UNSUPPORTEDFEATUREPROTO,
  '__module__' : 'apps.InterpreterMain_pb2'
  # @@protoc_insertion_point(class_scope:com.mammut.interpreter.UnsupportedFeatureProto)
  })
_sym_db.RegisterMessage(UnsupportedFeatureProto)

CompilerPhaseProto = _reflection.GeneratedProtocolMessageType('CompilerPhaseProto', (_message.Message,), {
  'DESCRIPTOR' : _COMPILERPHASEPROTO,
  '__module__' : 'apps.InterpreterMain_pb2'
  # @@protoc_insertion_point(class_scope:com.mammut.interpreter.CompilerPhaseProto)
  })
_sym_db.RegisterMessage(CompilerPhaseProto)

InterpreterPhaseProto = _reflection.GeneratedProtocolMessageType('InterpreterPhaseProto', (_message.Message,), {
  'DESCRIPTOR' : _INTERPRETERPHASEPROTO,
  '__module__' : 'apps.InterpreterMain_pb2'
  # @@protoc_insertion_point(class_scope:com.mammut.interpreter.InterpreterPhaseProto)
  })
_sym_db.RegisterMessage(InterpreterPhaseProto)

PropertyDescriptorNotFoundProto = _reflection.GeneratedProtocolMessageType('PropertyDescriptorNotFoundProto', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTYDESCRIPTORNOTFOUNDPROTO,
  '__module__' : 'apps.InterpreterMain_pb2'
  # @@protoc_insertion_point(class_scope:com.mammut.interpreter.PropertyDescriptorNotFoundProto)
  })
_sym_db.RegisterMessage(PropertyDescriptorNotFoundProto)

EdgeDescriptorNotFoundProto = _reflection.GeneratedProtocolMessageType('EdgeDescriptorNotFoundProto', (_message.Message,), {
  'DESCRIPTOR' : _EDGEDESCRIPTORNOTFOUNDPROTO,
  '__module__' : 'apps.InterpreterMain_pb2'
  # @@protoc_insertion_point(class_scope:com.mammut.interpreter.EdgeDescriptorNotFoundProto)
  })
_sym_db.RegisterMessage(EdgeDescriptorNotFoundProto)

PropertyValueNotFoundProto = _reflection.GeneratedProtocolMessageType('PropertyValueNotFoundProto', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTYVALUENOTFOUNDPROTO,
  '__module__' : 'apps.InterpreterMain_pb2'
  # @@protoc_insertion_point(class_scope:com.mammut.interpreter.PropertyValueNotFoundProto)
  })
_sym_db.RegisterMessage(PropertyValueNotFoundProto)

EdgeValueNotFoundProto = _reflection.GeneratedProtocolMessageType('EdgeValueNotFoundProto', (_message.Message,), {
  'DESCRIPTOR' : _EDGEVALUENOTFOUNDPROTO,
  '__module__' : 'apps.InterpreterMain_pb2'
  # @@protoc_insertion_point(class_scope:com.mammut.interpreter.EdgeValueNotFoundProto)
  })
_sym_db.RegisterMessage(EdgeValueNotFoundProto)

UnknownPropertyOrEdgeProto = _reflection.GeneratedProtocolMessageType('UnknownPropertyOrEdgeProto', (_message.Message,), {
  'DESCRIPTOR' : _UNKNOWNPROPERTYOREDGEPROTO,
  '__module__' : 'apps.InterpreterMain_pb2'
  # @@protoc_insertion_point(class_scope:com.mammut.interpreter.UnknownPropertyOrEdgeProto)
  })
_sym_db.RegisterMessage(UnknownPropertyOrEdgeProto)

OntologyTypeNotFoundProto = _reflection.GeneratedProtocolMessageType('OntologyTypeNotFoundProto', (_message.Message,), {
  'DESCRIPTOR' : _ONTOLOGYTYPENOTFOUNDPROTO,
  '__module__' : 'apps.InterpreterMain_pb2'
  # @@protoc_insertion_point(class_scope:com.mammut.interpreter.OntologyTypeNotFoundProto)
  })
_sym_db.RegisterMessage(OntologyTypeNotFoundProto)

VertexUndefinedProto = _reflection.GeneratedProtocolMessageType('VertexUndefinedProto', (_message.Message,), {
  'DESCRIPTOR' : _VERTEXUNDEFINEDPROTO,
  '__module__' : 'apps.InterpreterMain_pb2'
  # @@protoc_insertion_point(class_scope:com.mammut.interpreter.VertexUndefinedProto)
  })
_sym_db.RegisterMessage(VertexUndefinedProto)

SheetNotFoundProto = _reflection.GeneratedProtocolMessageType('SheetNotFoundProto', (_message.Message,), {
  'DESCRIPTOR' : _SHEETNOTFOUNDPROTO,
  '__module__' : 'apps.InterpreterMain_pb2'
  # @@protoc_insertion_point(class_scope:com.mammut.interpreter.SheetNotFoundProto)
  })
_sym_db.RegisterMessage(SheetNotFoundProto)

ReservedKeywordFoundProto = _reflection.GeneratedProtocolMessageType('ReservedKeywordFoundProto', (_message.Message,), {
  'DESCRIPTOR' : _RESERVEDKEYWORDFOUNDPROTO,
  '__module__' : 'apps.InterpreterMain_pb2'
  # @@protoc_insertion_point(class_scope:com.mammut.interpreter.ReservedKeywordFoundProto)
  })
_sym_db.RegisterMessage(ReservedKeywordFoundProto)

UnexpectedCompilerErrorProto = _reflection.GeneratedProtocolMessageType('UnexpectedCompilerErrorProto', (_message.Message,), {
  'DESCRIPTOR' : _UNEXPECTEDCOMPILERERRORPROTO,
  '__module__' : 'apps.InterpreterMain_pb2'
  # @@protoc_insertion_point(class_scope:com.mammut.interpreter.UnexpectedCompilerErrorProto)
  })
_sym_db.RegisterMessage(UnexpectedCompilerErrorProto)

ObjectUndefinedProto = _reflection.GeneratedProtocolMessageType('ObjectUndefinedProto', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTUNDEFINEDPROTO,
  '__module__' : 'apps.InterpreterMain_pb2'
  # @@protoc_insertion_point(class_scope:com.mammut.interpreter.ObjectUndefinedProto)
  })
_sym_db.RegisterMessage(ObjectUndefinedProto)

DefaultVertexPropertyNotFoundProto = _reflection.GeneratedProtocolMessageType('DefaultVertexPropertyNotFoundProto', (_message.Message,), {
  'DESCRIPTOR' : _DEFAULTVERTEXPROPERTYNOTFOUNDPROTO,
  '__module__' : 'apps.InterpreterMain_pb2'
  # @@protoc_insertion_point(class_scope:com.mammut.interpreter.DefaultVertexPropertyNotFoundProto)
  })
_sym_db.RegisterMessage(DefaultVertexPropertyNotFoundProto)

MultipleDefaultVertexPropertiesProto = _reflection.GeneratedProtocolMessageType('MultipleDefaultVertexPropertiesProto', (_message.Message,), {
  'DESCRIPTOR' : _MULTIPLEDEFAULTVERTEXPROPERTIESPROTO,
  '__module__' : 'apps.InterpreterMain_pb2'
  # @@protoc_insertion_point(class_scope:com.mammut.interpreter.MultipleDefaultVertexPropertiesProto)
  })
_sym_db.RegisterMessage(MultipleDefaultVertexPropertiesProto)

InterpreterMainOutput = _reflection.GeneratedProtocolMessageType('InterpreterMainOutput', (_message.Message,), {
  'DESCRIPTOR' : _INTERPRETERMAINOUTPUT,
  '__module__' : 'apps.InterpreterMain_pb2'
  # @@protoc_insertion_point(class_scope:com.mammut.interpreter.InterpreterMainOutput)
  })
_sym_db.RegisterMessage(InterpreterMainOutput)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
